@@ -84,7 +84,7 @@ getCDS <-
             }
             
             organism_name <- assembly_accession <- taxid <-
-                refseq_category <- version_status <- NULL
+                refseq_category <- version_status <- ftp_path <- NULL
             organism <-
                 stringr::str_replace_all(organism, "\\(", "")
             organism <-
@@ -100,7 +100,7 @@ getCDS <-
                             ((refseq_category == "representative genome") |
                                  (refseq_category == "reference genome")
                             ),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 } else {
                     FoundOrganism <-
@@ -110,7 +110,7 @@ getCDS <-
                             ((refseq_category == "representative genome") |
                                  (refseq_category == "reference genome")
                             ),
-                            (version_status == "latest"))
+                            (version_status == "latest"), !is.na(ftp_path))
                 }
             } else {
                 if (!is.taxid(organism)) {
@@ -119,14 +119,14 @@ getCDS <-
                             AssemblyFilesAllKingdoms,
                             stringr::str_detect(organism_name, organism) |
                                 stringr::str_detect(assembly_accession, organism),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 } else {
                     FoundOrganism <-
                         dplyr::filter(
                             AssemblyFilesAllKingdoms,
                             taxid == as.integer(organism),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 }
             }
@@ -322,7 +322,7 @@ getCDS <-
                         
                     )
                     
-                    readr::write_tsv(doc, path = file.path(path,paste0("doc_",local.org,"_db_",db,".tsv")))
+                    readr::write_tsv(doc, file = file.path(path,paste0("doc_",local.org,"_db_",db,".tsv")))
                     
                     message(
                         paste0(
@@ -504,7 +504,7 @@ getCDS <-
                     
                 )
                 
-                readr::write_tsv(doc, file.path(
+                readr::write_tsv(doc, file = file.path(
                     path,
                     paste0("doc_", new.organism, "_db_", db, ".tsv"))
                 )
@@ -672,7 +672,7 @@ getCDS <-
                     
                 )
                 
-                readr::write_tsv(doc, file.path(
+                readr::write_tsv(doc, file = file.path(
                     path,
                     paste0("doc_", new.organism, "_db_", db, ".tsv"))
                 )
