@@ -106,7 +106,7 @@ getProteome <-
             }
             
             organism_name <- assembly_accession <- taxid <- 
-                refseq_category <- version_status <- NULL
+                refseq_category <- version_status <- ftp_path <- NULL
             organism <-
                 stringr::str_replace_all(organism, "\\(", "")
             organism <-
@@ -122,7 +122,7 @@ getProteome <-
                             ((refseq_category == "representative genome") |
                                  (refseq_category == "reference genome")
                             ),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 } else {
                     FoundOrganism <-
@@ -132,7 +132,7 @@ getProteome <-
                             ((refseq_category == "representative genome") |
                                  (refseq_category == "reference genome")
                             ),
-                            (version_status == "latest"))
+                            (version_status == "latest"), !is.na(ftp_path))
                 }
             } else {
                 if (!is.taxid(organism)) {
@@ -141,14 +141,14 @@ getProteome <-
                             AssemblyFilesAllKingdoms,
                             stringr::str_detect(organism_name, organism) |
                                 stringr::str_detect(assembly_accession, organism),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 } else {
                     FoundOrganism <-
                         dplyr::filter(
                             AssemblyFilesAllKingdoms,
                             taxid == as.integer(organism),
-                            (version_status == "latest")
+                            (version_status == "latest"), !is.na(ftp_path)
                         ) 
                 }
             }
@@ -325,7 +325,7 @@ getProteome <-
                         
                     )
                     
-                    readr::write_tsv(doc, path = file.path(path,paste0("doc_",local.org,"_db_",db,".tsv")))
+                    readr::write_tsv(doc, file = file.path(path,paste0("doc_",local.org,"_db_",db,".tsv")))
                     
                     if (!gunzip) {
                             message(
@@ -506,7 +506,7 @@ getProteome <-
                         
                 )
                 
-                readr::write_tsv(doc, file.path(
+                readr::write_tsv(doc, file = file.path(
                         path,
                         paste0("doc_", new.organism, "_db_", db, ".tsv"))
                 )
@@ -673,7 +673,7 @@ getProteome <-
                         
                 )
                 
-                readr::write_tsv(doc, file.path(
+                readr::write_tsv(doc, file = file.path(
                         path,
                         paste0("doc_", new.organism, "_db_", db, ".tsv"))
                 )
