@@ -1,8 +1,10 @@
 context("Test: getKingdoms()")
 
 test_that("The getKingdoms() interface works properly..",{
+    skip_on_cran()
+    skip_on_travis()
     
-    testthat::equals(
+    expect_equal(
         getKingdoms(),
         c(
             "archaea",
